<?php
namespace Myquest\Controller;

use Doctrine\DBAL\Connection;
use Zeedhi\Framework\DataSource\DataSet;

class PesquisaController
{

    protected $entityManager;

    public function __construct($novoCodigo, $entityManager)
    {
        $this->novoCodigo = $novoCodigo;
        $this->entityManager = $entityManager;
    }

    public function getPesquisa($request, $response)
    {
        $sql = "SELECT PQ.NRQUESTIONARIO, IQ.NRORDEMQUESTAO, PQ.NRPROGRAMACAOPESQ, Q.NRQUESTAO, Q.TXQUESTAO, Q.IDTIPOQUESTAO, Q.IDQUESTAOOBRIGA, Q.IDOPCAORESPOSTA, Q.IDLAYOUTRESP, R.NRRESPOSTA, R.DSRESPOSTA, R.NRPROXIMAQUESTAO FROM   QUESTAO Q LEFT JOIN RESPOSTA R ON Q.NRQUESTAO = R.NRQUESTAO INNER JOIN ITEMQUESTIONARIO IQ ON IQ.NRQUESTAO = Q.NRQUESTAO INNER JOIN PROGRAMACAOPESQ PQ ON PQ.NRQUESTIONARIO = IQ.NRQUESTIONARIO WHERE  PQ.NRPROGRAMACAOPESQ = ( SELECT MAX(P.NRPROGRAMACAOPESQ) FROM   PROGRAMACAOPESQ P WHERE  ( P.IDAPLICATIVO = 'MYQUEST' ) AND ( TRUNC(SYSDATE) BETWEEN TRUNC(P.DTINICIO) AND TRUNC(P.DTFIM) ) AND ( P.NRORG = :NRORG ) AND ( P.CDFILIAL = :CDFILIAL ) AND ( NVL(P.NRLOCALPESQ, :NRLOCALPESQ) = :NRLOCALPESQ OR :NRLOCALPESQ IS NULL ) AND ( TO_CHAR(SYSDATE, 'HH24MI') BETWEEN P.HRINICIO AND P.HRFIM ) ) ORDER  BY IQ.NRORDEMQUESTAO, R.NRORDENARESPOST";
        $conn = $this
            ->entityManager
            ->getConnection();
        $row = $request->getRow();
        $params = ['NRORG' => $row['NRORG'], 'CDFILIAL' => $row['CDFILIAL'], 'NRLOCALPESQ' => $row['NRLOCALPESQ']];

        $statement = $conn->prepare($sql);
        $statement->execute($params);

        $result = $statement->fetchAll();
        $response->addDataSet(new DataSet('pesquisa', $result));
    }

    public function getQuestao($request, $response)
    {
        $sql = "SELECT Q.NRQUESTAO, Q.TXQUESTAO, Q.IDTIPOQUESTAO, Q.IDQUESTAOOBRIGA, Q.IDOPCAORESPOSTA, R.NRRESPOSTA, R.DSRESPOSTA, R.NRPROXIMAQUESTAO, Q.IDLAYOUTRESP FROM QUESTAO Q LEFT JOIN RESPOSTA R ON Q.NRQUESTAO = R.NRQUESTAO WHERE Q.NRQUESTAO = :NRPROXIMAQUESTAO ORDER BY R.NRORDENARESPOST";
        $conn = $this
            ->entityManager
            ->getConnection();
        $row = $request->getRow();
        $params = ['NRPROXIMAQUESTAO' => $row['NRPROXIMAQUESTAO']];

        $statement = $conn->prepare($sql);

        $statement->execute($params);
        $result = $statement->fetchAll();
        $response->addDataSet(new DataSet('questao', $result));

    }

    public function insertAnswers($request, $response)
    {
        $sqlEXECUCAOPESQ = "INSERT INTO EXECUCAOPESQ (NREXECUCAOPESQ, CDFILIAL, NRLOCALPESQ, NRQUESTIONARIO, IDAPLICATIVO, NRUSUARIOPESQ, DTHRINICIOPESQ, DTHRFIMPESQ, NRORG, NRPROGRAMACAOPESQ) VALUES ( ?, ?, ?, ?, ?, ?, ?, ?, ?, ? )";
        $sqlRESPOSTAPESQ = "INSERT INTO RESPOSTAPESQ (NRRESPOSTAPESQ, NREXECUCAOPESQ, NRQUESTAO, TXRESPOSTAPESQ, NRRESPOSTA, NRORG, NRRESPOSTAANTERIOR) VALUES(?, ?, ?, ?, ?, ?, ?)";
        // $sqlEXECUCAOPESQ = "INSERT INTO EXECUCAOPESQ (NREXECUCAOPESQ, CDFILIAL, NRLOCALPESQ, NRQUESTIONARIO, IDAPLICATIVO, NRUSUARIOPESQ, DTHRINICIOPESQ, DTHRFIMPESQ, NRORG, NRPROGRAMACAOPESQ) VALUES ( :NREXECUCAOPESQ, :CDFILIAL, :NRLOCALPESQ, :NRQUESTIONARIO, :IDAPLICATIVO, :NRUSUARIOPESQ, :DTHRINICIOPESQ, :DTHRFIMPESQ, :NRORG, :NRPROGRAMACAOPESQ )";
        //$sqlRESPOSTAPESQ = "INSERT INTO RESPOSTAPESQ (NRRESPOSTAPESQ, NREXECUCAOPESQ, NRQUESTAO, TXRESPOSTAPESQ, NRRESPOSTA, NRORG, NRRESPOSTAANTERIOR) VALUES(:NRRESPOSTAPESQ, :NREXECUCAOPESQ, :NRQUESTAO, :TXRESPOSTAPESQ, :NRRESPOSTA, :NRORG, :NRRESPOSTAANTERIOR)";

        $row = $request->getRow();
        $NRORG = $row['filteredData']['NRORG'];
        $CDFILIAL = $row['filteredData']['CDFILIAL'];
        $NRLOCALPESQ = $row['filteredData']['NRLOCALPESQ'];

        $answers = $row['answers'];
        $startTime = $answers[0]['answeredOn'];
        $endTime = $answers[count($answers) - 1]['answeredOn'];

        $NREXECUCAOPESQ = $this
            ->novoCodigo
            ->getCodeByTableName('EXECUCAOPESQ', $NRORG, 1, 10, false);
        $params = array(
            'NREXECUCAOPESQ' => $NREXECUCAOPESQ,
            'CDFILIAL' => $CDFILIAL,
            'NRLOCALPESQ' => $NRLOCALPESQ,
            'NRQUESTIONARIO' => $row['surveyData']['NRQUESTIONARIO'],
            'IDAPLICATIVO' => "MYQUEST",
            'NRUSUARIOPESQ' => null,
            'DTHRINICIOPESQ' => $startTime,
            'DTHRFIMPESQ' => $endTime,
            'NRORG' => $NRORG,
            'NRPROGRAMACAOPESQ' => $row['surveyData']['NRPROGRAMACAOPESQ'],
        );

        $this->executeInsertSql($sqlEXECUCAOPESQ, [$params['NREXECUCAOPESQ'], $params['CDFILIAL'], $params['NRLOCALPESQ'], $params['NRQUESTIONARIO'], $params['IDAPLICATIVO'], $params['NRUSUARIOPESQ'], $params['DTHRINICIOPESQ'], $params['DTHRFIMPESQ'], $params['NRORG'], $params['NRPROGRAMACAOPESQ']]);
        foreach ($answers as $answer)
        {
            if (!isset($answer['selectedOptions']))
            {
                $NRRESPOSTAPESQ = $this
                    ->novoCodigo
                    ->getCodeByTableName('RESPOSTAPESQ', $NRORG, 1, 10, false);
                // $params2 = array(
                //     'NREXECUCAOPESQ' => $NREXECUCAOPESQ,
                //     'NRRESPOSTAPESQ' => $NRRESPOSTAPESQ,
                //     'NRQUESTAO' => $answer['NRQUESTAO'],
                //     'TXRESPOSTAPESQ' => $answer['TXRESPOSTAPESQ'],
                //     'NRRESPOSTA' => isset($answer['NRRESPOSTA']) ? $answer['NRRESPOSTA'] : null,
                //     'NRORG' => $NRORG,
                //     'NRRESPOSTAANTERIOR' => $answer['NRRESPOSTAANTERIOR'],
                // );
                $this->executeInsertSql($sqlRESPOSTAPESQ, [ $NRRESPOSTAPESQ, $NREXECUCAOPESQ, $answer['NRQUESTAO'], $answer['TXRESPOSTAPESQ'], isset($answer['NRRESPOSTA']) ? $answer['NRRESPOSTA'] : null, $NRORG, $answer['NRRESPOSTAANTERIOR']]);
            }
            else
            {
                foreach ($answer['selectedOptions'] as $selectedOption)
                {
                    $NRRESPOSTAPESQ = $this
                        ->novoCodigo
                        ->getCodeByTableName('RESPOSTAPESQ', $NRORG, 1, 10, false);
                    // $params2 = array(
                    //     'NREXECUCAOPESQ' => $NREXECUCAOPESQ,
                    //     'NRRESPOSTAPESQ' => $NRRESPOSTAPESQ,
                    //     'NRQUESTAO' => $answer['NRQUESTAO'],
                    //     'TXRESPOSTAPESQ' => $selectedOption['DSRESPOSTA'],
                    //     'NRRESPOSTA' => $selectedOption['NRRESPOSTA'],
                    //     'NRORG' => $NRORG,
                    //     'NRRESPOSTAANTERIOR' => $answer['NRRESPOSTAANTERIOR'],
                    // );
                    $this->executeInsertSql($sqlRESPOSTAPESQ, [ $NRRESPOSTAPESQ, $NREXECUCAOPESQ, $answer['NRQUESTAO'], $selectedOption['DSRESPOSTA'], $selectedOption['NRRESPOSTA'], $NRORG, $answer['NRRESPOSTAANTERIOR']]);
                }
            }
        }
    }
    
    protected function executeInsertSql($sql, $params = null)
    {
        $conn = $this->entityManager->getConnection();
        $statement = $conn->prepare($sql);
        $statement->execute($params);
    }
}

